==> xlniuxdata-vipgame-1.0.8-sources.jar: com/xunlei/niux/data/vipgame/vo/business/AgentPlatform.java <==
package com.xunlei.niux.data.vipgame.vo.business;


import com.ferret.common.dao.annotation.Table;


/**
 * @author lisu
 *  2015-01-08
 */
@Table(tableName = "agentplatform", pkFieldName = "seqId", pkFieldAssign = false)
public class AgentPlatform {
      private Long seqId;
      private String platformNo;
      private String platformName;
      private String remark;
      private String inputBy;
      private String inputTime;
      private String editBy;
      private String editTime;
      
       
	public String getRemark() {
		return remark;
	}
	public void setRemark(String remark) {
		this.remark = remark;
	}
		public Long getSeqId() {
			return seqId;
		}
		public void setSeqId(Long seqId) {
			this.seqId = seqId;
		}
		public String getPlatformNo() {
			return platformNo;
		}
		public void setPlatformNo(String platformNo) {
			this.platformNo = platformNo;
		}
		public String getPlatformName() {
			return platformName;
		}
		public void setPlatformName(String platformName) {
			this.platformName = platformName;
		}
		public String getInputBy() {
			return inputBy;
		}
		public void setInputBy(String inputBy) {
			this.inputBy = inputBy;
		}
		public String getInputTime() {
			return inputTime;
		}
		public void setInputTime(String inputTime) {
			this.inputTime = inputTime;
		}
		public String getEditBy() {
			return editBy;
		}
		public void setEditBy(String editBy) {
			this.editBy = editBy;
		}
		public String getEditTime() {
			return editTime;
		}
		public void setEditTime(String editTime) {
			this.editTime = editTime;
		}
	      
      
      
}

==> xlniuxdata-vipgame-1.0.65-20161208.100953-44-sources.jar: com/xunlei/niux/data/vipgame/vo/business/AgentPlatform.java <==
package com.xunlei.niux.data.vipgame.vo.business;


import com.ferret.common.dao.annotation.Table;


/**
 * @author lisu
 *  2015-01-08
 */
@Table(tableName = "agentplatform", pkFieldName = "seqId", pkFieldAssign = false)
public class AgentPlatform {
      private Long seqId;
      private String platformNo;
      private String platformName;
      private String remark;
      private String inputBy;
      private String inputTime;
      private String editBy;
      private String editTime;
      private String userId;
      
       
	public String getUserId() {
		return userId;
	}
	public void setUserId(String userId) {
		this.userId = userId;
	}
	public String getRemark() {
		return remark;
	}
	public void setRemark(String remark) {
		this.remark = remark;
	}
		public Long getSeqId() {
			return seqId;
		}
		public void setSeqId(Long seqId) {
			this.seqId = seqId;
		}
		public String getPlatformNo() {
			return platformNo;
		}
		public void setPlatformNo(String platformNo) {
			this.platformNo = platformNo;
		}
		public String getPlatformName() {
			return platformName;
		}
		public void setPlatformName(String platformName) {
			this.platformName = platformName;
		}
		public String getInputBy() {
			return inputBy;
		}
		public void setInputBy(String inputBy) {
			this.inputBy = inputBy;
		}
		public String getInputTime() {
			return inputTime;
		}
		public void setInputTime(String inputTime) {
			this.inputTime = inputTime;
		}
		public String getEditBy() {
			return editBy;
		}
		public void setEditBy(String editBy) {
			this.editBy = editBy;
		}
		public String getEditTime() {
			return editTime;
		}
		public void setEditTime(String editTime) {
			this.editTime = editTime;
		}
	      
      
      
}
